==> ah-formbuilder-1.1.2.tgz: package/es/utils/date-validation/EmailSelects.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/utils/date-validation/EmailSelects.js";
import React from 'react';
import { FormLabel, FormControl, FormHelperText } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import EmailComplete from '../../utils/selects/EmailComplete';
import InputLabel from "@material-ui/core/InputLabel";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function EmailSelects(props) {
  var sendTo = props.sendTo,
      sendToExternal = props.sendToExternal,
      cc = props.cc,
      ccExternal = props.ccExternal,
      bcc = props.bcc,
      bccExternal = props.bccExternal,
      handleChange = props.handleChange,
      roles = props.roles,
      error = props.error,
      required = props.required;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("div", {
    className: "w-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 18,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 19,
      columnNumber: 13
    }
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 17
    }
  }, "Recipients"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select recipient(s)',
    internal: sendTo,
    external: sendToExternal,
    onChange: function onChange(internal, external) {
      return handleChange('send_to', internal, external);
    },
    data: roles,
    id: "recipient",
    includeSelectAll: false,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 24,
      columnNumber: 17
    }
  }), error && /*#__PURE__*/React.createElement(FormHelperText, {
    error: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 33,
      columnNumber: 27
    }
  }, error)), /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 35,
      columnNumber: 13
    }
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 36,
      columnNumber: 17
    }
  }, "CC"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select cc(s)',
    internal: cc,
    external: ccExternal,
    onChange: function onChange(internal, external) {
      return handleChange('cc', internal, external);
    },
    data: roles,
    id: "cc",
    includeSelectAll: false,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 39,
      columnNumber: 17
    }
  })), /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 49,
      columnNumber: 13
    }
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 50,
      columnNumber: 17
    }
  }, "BCC"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select bcc(s)',
    internal: bcc,
    external: bccExternal,
    onChange: function onChange(internal, external) {
      return handleChange('bcc', internal, external);
    },
    data: roles,
    id: "cc",
    includeSelectAll: false,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 53,
      columnNumber: 17
    }
  })));
}

==> ah-formbuilder-1.2.6.tgz: package/es/utils/date-validation/EmailSelects.js <==
import React from 'react';
import { FormLabel, FormControl, FormHelperText } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import EmailComplete from '../../utils/selects/EmailComplete';
import InputLabel from "@material-ui/core/InputLabel";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});
export default function EmailSelects(props) {
  var sendTo = props.sendTo,
    sendToExternal = props.sendToExternal,
    cc = props.cc,
    ccExternal = props.ccExternal,
    bcc = props.bcc,
    bccExternal = props.bccExternal,
    handleChange = props.handleChange,
    roles = props.roles,
    error = props.error,
    required = props.required;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement("div", {
    className: "w-full"
  }, /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center"
  }, "Recipients"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select recipient(s)',
    internal: sendTo,
    external: sendToExternal,
    onChange: function onChange(internal, external) {
      return handleChange('send_to', internal, external);
    },
    data: roles,
    id: "recipient",
    includeSelectAll: false
  }), error && /*#__PURE__*/React.createElement(FormHelperText, {
    error: true
  }, error)), /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center"
  }, "CC"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select cc(s)',
    internal: cc,
    external: ccExternal,
    onChange: function onChange(internal, external) {
      return handleChange('cc', internal, external);
    },
    data: roles,
    id: "cc",
    includeSelectAll: false
  })), /*#__PURE__*/React.createElement(FormControl, {
    className: "p-16",
    fullWidth: true
  }, /*#__PURE__*/React.createElement("label", {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    className: "ahfb-mt-2 ahfb-mb-2 ahfb-align-center"
  }, "BCC"), /*#__PURE__*/React.createElement(EmailComplete, {
    placeholder: 'Please select bcc(s)',
    internal: bcc,
    external: bccExternal,
    onChange: function onChange(internal, external) {
      return handleChange('bcc', internal, external);
    },
    data: roles,
    id: "cc",
    includeSelectAll: false
  })));
}
